Attribute VB_Name = "PhVintDigOut"
Option Explicit

   ' ========================================================================
   ' PhidgetDigitalOutput  OUT1100  (4 digital outputs 30Vdc 8A)
   '
   ' The Digital Output class is used to control digital logic outputs and
   ' LED outputs on Phidgets boards.

   ' ========================================================================
   ' PhidgetDigitalOutput_create(
   '    PhidgetDigitalOutputHandle *ch
   '    )
   ' Parameters:    ch:   The channel handle
   ' Return:              The Phidget return code
   '
   ' Creates an instance of a Phidget channel.  Once created the channel may
   ' need to be configured to match the physical device and channel index you
   ' want to attach to, and then be opened by calling Phidget_open() .
   ' The channel handle must be released with PhidgetDigitalOutput_delete() .
   '
   Public Declare Function PhDigOutCreate& _
      Lib "Phidget22.dll" _
      Alias "PhidgetDigitalOutput_create" ( _
      ByRef handle&)

   ' ========================================================================
   ' PhidgetDigitalOutput_delete(
   '    PhidgetDigitalOutputHandle *ch
   '    )
   ' Parameters:
   '   PhidgetDigitalOutputHandle ch:   The channel handle
   ' Return:                            The Phidget return code
   '
   ' Releases a Phidget channel handle created with PhidgetDigitalOutput_create()
   ' If the channel is open when called, it will be closed.
   '
   Public Declare Function PhDigOutDelete& _
      Lib "Phidget22.dll" _
      Alias "PhidgetDigitalOutput_delete" ( _
      ByRef handle&)

   ' ========================================================================
   ' PhidgetDigitalOutput_getDutyCycle(
   '    PhidgetDigitalOutputHandle ch,
   '    double *dutyCycle
   '    )
   ' Parameters:
   '  PhidgetDigitalOutputHandle ch:   The channel handle
   '         dutyCycle:   Long value pointer to the duty cycle value (double#)
   ' Return:              The Phidget return code
   ' Default:             0.0 duty cycle
   '
   ' The DutyCycle represents the fraction of time the output is on (high).
   ' A DutyCycle of 1.0 translates to a high output, a DutyCycle of 0 translates
   ' to a low output.  A DutyCycle of 0.5 translates to an output that is high
   ' half the time, which results in an average output voltage of (output
   ' voltage x 0.5) You can use the DutyCycle to create a dimming effect on LEDs.
   '
   Public Declare Function PhDigOutGetDutyCycle& _
      Lib "Phidget22.dll" _
      Alias "PhidgetDigitalOutput_getDutyCycle" ( _
      ByVal handle&, _
      ByRef dutyCycle#)

   ' ========================================================================
   ' PhidgetDigitalOutput_setDutyCycle(
   '    PhidgetDigitalOutputHandle ch,
   '    double dutyCycle
   '    )
   ' Parameters:
   '  PhidgetDigitalOutputHandle ch:   The channel handle
   '         dutyCycle:   The duty cycle value      (Default: 0.0 duty cycle)
   ' Return:              The Phidget return code
   ' Default:             0.0# duty cycle
   '
   ' The DutyCycle represents the fraction of time the output is on (high).
   ' This will override the State setting on the channel. A DutyCycle of 1.0
   ' translates to a high output, a DutyCycle of 0 translates to a low output.
   ' This is equivalent to setting a State of TRUE and FALSE respectively.
   ' A DutyCycle of 0.5 translates to an output that is high half the time,
   ' which results in an average output voltage of (output voltage x 0.5)
   ' You can use the DutyCycle to create a dimming effect on LEDs.
   '
   Public Declare Function PhDigOutSetDutyCycle& _
      Lib "Phidget22.dll" _
      Alias "PhidgetDigitalOutput_setDutyCycle" ( _
      ByVal handle&, _
      ByVal dutyCycle#)

   ' ========================================================================
   ' PhidgetDigitalOutput_setDutyCycle_async(
   '    PhidgetDigitalOutputHandle ch,
   '    double dutyCycle,
   '    void (CCONV *asyncHandler)(PhidgetHandle phid,
   '          void *ctx,
   '          PhidgetReturnCode res),
   '    void *ctx
   '    )
   ' Parameters:
   '  PhidgetDigitalOutputHandle ch:   The channel handle
   '         dutyCycle:   The duty cycle value
   '      asyncHandler:   Pointer to Asynchronous completion callback
   '               ctx:   User supplied context pointer
   ' Return:              The Phidget return code
   '
   ' The DutyCycle represents the fraction of time the output is on (high).
   ' This will override the State setting on the channel. A DutyCycle of 1.0
   ' translates to a high output, a DutyCycle of 0 translates to a low output.
   ' This is equivalent to setting a State of TRUE and FALSE respectively. A
   ' DutyCycle of 0.5 translates to an output that is high half the time,
   ' which results in an average output voltage of V * 0.5.  You can use the
   ' DutyCycle to create a dimming effect on LEDs.
   '
   ' This function requires PhDigOutOnSetDutyCycleAsync& callback proceedure
   ' AsyncHandlerPtr& must be set to AddressOf PhDigOutOnSetDutyCycleAsync&
   Public Declare Function PhDigOutSetDutyCycleAsync& _
      Lib "Phidget22.dll" _
      Alias "PhidgetDigitalOutput_setDutyCycle_async" ( _
      ByVal handle&, _
      ByVal dutyCycle#, _
      ByVal asyncHandlerCallbackPtr&, _
      ByRef userData&)

   ' ========================================================================
   ' PhidgetDigitalOutput_getMinDutyCycle(
   '    PhidgetDigitalOutputHandle ch,
   '    double *minDutyCycle
   '    )
   ' Parameters:
   '  PhidgetDigitalOutputHandle ch:   The channel handle
   '      minDutyCycle:   The duty cycle value
   ' Return:              The Phidget return code
   ' Constant:            Pointer to 0.0# duty cycle
   '
   ' The minimum value that DutyCycle can be set to.
   '
   Public Declare Function PhDigOutGetMinDutyCycle& _
      Lib "Phidget22.dll" _
      Alias "PhidgetDigitalOutput_getMinDutyCycle" ( _
      ByVal handle&, _
      ByRef minDutyCycle#)

   ' ========================================================================
   ' PhidgetDigitalOutput_getMaxDutyCycle(
   '    PhidgetDigitalOutputHandle ch,
   '    double *maxDutyCycle
   '    )
   ' Parameters:
   '  PhidgetDigitalOutputHandle ch:   The channel handle
   '      maxDutyCycle:   The duty cycle value
   ' Return:              The Phidget return code
   ' Constant:            Pointer to 0.0# duty cycle
   '
   ' The maximum value that DutyCycle can be set to.
   '
   Public Declare Function PhDigOutGetMaxDutyCycle& _
      Lib "Phidget22.dll" _
      Alias "PhidgetDigitalOutput_getMaxDutyCycle" ( _
      ByVal handle&, _
      ByRef maxDutyCycle#)

   ' ========================================================================
   ' PhidgetDigitalOutput_getState(
   '    PhidgetDigitalOutputHandle ch,
   '    int *state
   '    )
   ' Parameters:
   '  PhidgetDigitalOutputHandle ch:   The channel handle
   '             state:   Pointer to the state value (16bit true false)
   ' Return:              The Phidget return code
   ' Default:             0
   '
   ' The State will indicate whether the output is high (TRUE) or low (FALSE).
   ' If a DutyCycle has been set, the state will return as TRUE if the
   ' DutyCycle is above 0.5, or FALSE otherwise.
   '
   ' Note: This appears to be incorrect.
   '       The state& is high when DutyCycle is >0.
   '
   Public Declare Function PhDigOutGetState& _
      Lib "Phidget22.dll" _
      Alias "PhidgetDigitalOutput_getState" ( _
      ByVal handle&, _
      ByRef state&)

   ' ========================================================================
   ' PhidgetDigitalOutput_setState(
   '    PhidgetDigitalOutputHandle ch,
   '    int  state
   '    )
   ' Parameters:    ch:   The channel handle
   '             state:   The state value (16bit)
   ' Return:              The Phidget return code
   ' Default:             0
   '
   ' The State will dictate whether the output is high (TRUE) or Low (FALSE).
   ' This will override any DutyCycle that may have been set on the channel.
   ' Setting the State to TRUE is the same as setting DutyCycle to 1.0, and
   ' setting the State to FALSE is the same as setting a DutyCycle of 0.0.
   '
   Public Declare Function PhDigOutSetState& _
      Lib "Phidget22.dll" _
      Alias "PhidgetDigitalOutput_setState" ( _
      ByVal handle&, _
      ByVal state&)

   ' ========================================================================
   ' PhidgetDigitalOutput_setState_async(
   '    PhidgetDigitalOutputHandle ch,
   '    int  state,
   '    void (CCONV *asyncHandler)(PhidgetHandle phid, void *ctxPtr,
   '                               PhidgetReturnCode res),
   '    void *ctxtr
   '    )
   ' Parameters:    ch:   The channel handle
   '             state:   The state value
   '      asyncHandler:   Asynchronous completion callback address
   '               ctx:   User supplied context pointer
   ' Return:              The Phidget return code
   ' Default:             0
   '
   ' The State will dictate whether the output is constantly high (TRUE) or Low
   ' (FALSE). This will override any DutyCycle that may have been set on the
   ' channel. Setting the State to TRUE is the same as setting DutyCycle to 1.0,
   ' and setting the State to FALSE is the same as setting a DutyCycle of 0.0.
   '
   Public Declare Function PhidgetDigitalOutput_setState_async _
      Lib "Phidget22.dll" ( _
      ByVal handle&, _
      ByVal state&, _
      ByVal AsyncHandlerPtr&, _
      ByRef userData&)

   ' ========================================================================
   ' PhidgetReturnCode Enumerations:
   ' Name                    Value  Description
   '
   ' EPHIDGET_OK             0x0    Success
   ' EPHIDGET_PERM           0x1    Not Permitted
   ' EPHIDGET_NOENT          0x2    No Such Entity
   ' EPHIDGET_TIMEOUT        0x3    Timed Out
   ' EPHIDGET_KEEPALIVE      0x3a   Keep Alive Failure
   ' EPHIDGET_INTERRUPTED    0x4    Op Interrupted
   ' EPHIDGET_IO             0x5    IO Issue
   ' EPHIDGET_NOMEMORY       0x6    Memory Issue
   ' EPHIDGET_ACCESS         0x7    Access (Permission) Issue
   ' EPHIDGET_FAULT          0x8    Address Issue
   ' EPHIDGET_BUSY           0x9    Resource Busy
   ' EPHIDGET_EXIST          0xa    Object Exists
   ' EPHIDGET_NOTDIR         0xb    Object is not a directory
   ' EPHIDGET_ISDIR          0xc    Object is a directory
   ' EPHIDGET_INVALID        0xd    Invalid
   ' EPHIDGET_NFILE          0xe    Too many open files in system
   ' EPHIDGET_MFILE          0xf    Too many open files
   ' EPHIDGET_NOSPC          0x10   Not enough space
   ' EPHIDGET_FBIG           0x11   File too Big
   ' EPHIDGET_ROFS           0x12   Read Only Filesystem
   ' EPHIDGET_RO             0x13   Read Only Object
   ' EPHIDGET_UNSUPPORTED    0x14   Operation Not SuphubPorted
   ' EPHIDGET_INVALIDARG     0x15   Invalid Argument
   ' EPHIDGET_AGAIN          0x16   Try again
   ' EPHIDGET_NOTEMPTY       0x1a   No Empty
   ' EPHIDGET_UNEXPECTED     0x1c   Unexpected Error
   ' EPHIDGET_DUPLICATE      0x1b   Duplicate
   ' EPHIDGET_BADPASSWORD    0x25   Bad Credential
   ' EPHIDGET_NETUNAVAIL     0x2d   Network Unavailable
   ' EPHIDGET_CONNREF        0x23   Connection Refused
   ' EPHIDGET_CONNRESET      0x2e   Connection Reset
   ' EPHIDGET_HOSTUNREACH    0x30   No route to host
   ' EPHIDGET_NODEV          0x28   No Such Device
   ' EPHIDGET_WRONGDEVICE    0x32   Wrong Device
   ' EPHIDGET_PIPE           0x29   Broken Pipe
   ' EPHIDGET_RESOLV         0x2c   Name Resolution Failure
   ' EPHIDGET_UNKNOWNVAL     0x33   Unknown or Invalid Value
   ' EPHIDGET_NOTATTACHED    0x34   Device not Attached
   ' EPHIDGET_INVALIDPACKET  0x35   Invalid or Unexpected Packet
   ' EPHIDGET_2BIG           0x36   Argument List Too Long
   ' EPHIDGET_BADVERSION     0x37   Bad Version
   ' EPHIDGET_CLOSED         0x38   Closed
   ' EPHIDGET_NOTCONFIGURED  0x39   Not Configured
   ' EPHIDGET_EOF            0x1f   End of File





'===========================================================================
' PHIDGET 1057 ENCODER STARTUP
'===========================================================================


'===========================================================================
' EVENT HANDLERS
'===========================================================================

'===========================================================================
Public Static Sub PhDigOutOnAttach( _
   ByVal handle&, _
   ByRef userData&)

   ' ********** User code HERE *********
   ' userData& = indx%   Label and Button index is also the same
   Form1.Label6(userData&) = "Attached"
   Form1.Label8(userData&) = userData&
   ' ***********************************
   
End Sub

'===========================================================================
'int CCONV DetachHandler(CPhidgetHandle ENC, void *userptr)
Public Static Sub PhDigOutOnDetach( _
   ByVal handle&, _
   ByRef userData&)

   ' ********** User code HERE *********
   Form1.Label6(userData&) = "Detached"
   Form1.Label8(userData&) = "---"
   ' ***********************************
  
End Sub

'===========================================================================
Public Static Sub PhDigOutOnError( _
      ByVal handle&, _
      ByRef userData&, _
      ByVal errorCode&, _
      ByRef descriptionPtr&)

   ' ********** User code HERE *********
   Call Form1.DisplayStatus("PhDigOutOnError ", errorCode&)
   
   ' ***********************************
   
End Sub

''===========================================================================
'   '' SETUP DUTY CYCLE ASYNC HANDLER
'   'stat& = PhDigOutSetDutyCycleAsync(PhHndl&(isHub&,port,ch&), _
'   '            dutyCycle#, _
'   '            AddressOf PhDigOutOnSetDutyCycleAsync, _
'   '            userData&) ' returned with event for this handle
'   'If stat& <> 0 Then Exit Sub
'
'
'Public Static Sub PhDigOutOnSetDutyCycleAsync( _
'      ByVal handle&, _
'      ByRef userData&)
'
'   ' ********** User code HERE *********
'   '
'   ' ***********************************
'End Sub

