Attribute VB_Name = "PhVintSetup"
Option Explicit

   ' Create a TYPE for the data required for each I/O point
   Public Type ChInfo
      hubSn As Long     ' Entered by user
      isHub As Long     ' Entered by user (1 if using Hub Port as I/O point)
      port As Long      ' Entered by user (Hub Port number)
      ch As Long        ' Entered by user (module channel number) (0 if Hub)
      hndl As Long      ' Handle is created with 'Create'
      uDat As Long      ' Index of Dev() array
   End Type
      
   ' Make an array large enough for all I/O points
   Public Dev(31) As ChInfo ' 0-31
   
   ' Typical C++ data type for VINT (from Phidgets C++ example)
   '
   '   Public Type NetInfo
   '      isRemote As Long
   '      serverDiscovery As Long
   '      hostName As String
   '      netPort As Long
   '      password As String
   '   End Type
   '
   '   Public Type ChInfo
   '      deviceSerialNumber As Long
   '      hubPort As Long
   '      channel As Long
   '      isHub As Long  ' Is this a Hub Port device
   '      isVINT As Long ' Is this a VINT device
   '      netInf As NetInfo
   '   End Type

'===========================================================================
Static Sub SetupAllIoPoints(stat&)
   ' User setup data
   ' Enter SN#, isHub, port, and ch for each I/O point
   
   Dim indx%
   
   ' =================================================
   indx% = 0
   Dev(indx%).hubSn = 527576  ' Enter SN# for YOUR hub
   Dev(indx%).isHub = 0       ' Located on REL1100
   Dev(indx%).port = 0        ' Hub port for REL1100 (0-5)
   Dev(indx%).ch = 0          ' Channel on REL1100 (0-3)
   Dev(indx%).uDat = indx%    ' index of Dev() array
   Call SetupPhDigOut(Dev(indx%), stat&) ' Create Dev(indx%).hndl
   ' Note: uDat& can be any long value.
   '       It is returned with events for this I/O point
   '       I'm using it as an index for Dev() array
   '       Dev(indx) is returned as with events as userData.
   '       This is used to index the Dev() array for data
   
   ' =================================================
   indx% = 1
   Dev(indx%).hubSn = 527576  ' Serial number for MY hub
   Dev(indx%).isHub = 0       ' Located on REL1100
   Dev(indx%).port = 0        ' Hub port for REL1100 (0-5)
   Dev(indx%).ch = 1          ' Channel on REL1100 (0-3)
   Dev(indx%).uDat = indx%    ' index of Dev() array
   Call SetupPhDigOut(Dev(indx%), stat&) ' Create Dev(indx%).hndl
   
   ' =================================================
   indx% = 2
   Dev(indx%).hubSn = 527576  ' SN# for hub
   Dev(indx%).isHub = 0       ' 1 = On Hub   2 = On Module
   Dev(indx%).port = 0        ' Hub port number (0-5)
   Dev(indx%).ch = 2          ' Module channel or 0 for Hub
   Dev(indx%).uDat = indx%    ' index of Dev() array
   Call SetupPhDigOut(Dev(indx%), stat&) ' Create Dev(indx%).hndl
   
   ' =================================================
   indx% = 3
   Dev(indx%).hubSn = 527576  ' Enter SN# for YOUR hub
   Dev(indx%).isHub = 0       ' Located on REL1100
   Dev(indx%).port = 0        ' Hub port for REL1100 (0-5)
   Dev(indx%).ch = 3          ' Channel on REL1100 (0-3)
   Dev(indx%).uDat = indx%    ' index of Dev() array
   Call SetupPhDigOut(Dev(indx%), stat&)  ' Create Dev(indx%).hndl
   
   ' =================================================
   ' Setup VINT Hub hubPort 5 for Digital Output Mode (LED)
   ' All hub hubPorts used for I/O are channel 0
   indx% = 4
   Dev(indx%).hubSn = 527576  ' Enter SN# for YOUR hub
   Dev(indx%).isHub = 1       ' Located on hub
   Dev(indx%).port = 5        ' Hub port (0-5)
   Dev(indx%).ch = 0          ' Channel on Hub (always 0)
   Dev(indx%).uDat = indx%    ' index of Dev() array
   Call SetupPhDigOut(Dev(indx%), stat&)  ' Create Dev(indx%).hndl
   
End Sub

'===========================================================================
Public Static Sub SetupPhDigOut(ioData As ChInfo, stat&)
   ' Enter: ioData
   ' Exit:  ioData.hndl&
   '        stat&  0=OK
   
   ' Create, configure, and open a DigitalOutput channel.
   ' stat& = 0 if the program exits successfully
   
   Dim dutyCycle#
   Const timeOutMs& = 3000
   
   dutyCycle# = 0#
   
   On Error Resume Next
   stat& = 0& ' Set default OK
   
   ' ===================================
   ' Create an instance of a Phidget channel.  Once created the
   ' channel may need to be configured to match the physical
   ' device and channel you want to attach to, and then be
   ' opened by calling Phidget_open().  The channel handle must
   ' be released with PhidgetDigitalOutput_delete().
   '
   ' retVal& (Error Code) will always be 0 if no Errors
   '
   stat& = PhDigOutCreate&(ioData.hndl) ' Create new handle
   If stat& <> 0 Then Exit Sub
   
   ' SET SERIAL NUMBER
   stat& = PhSetDeviceSerialNumber(ioData.hndl, ioData.hubSn)
   If stat& <> 0 Then Exit Sub

   ' SET ISHUB (0 if hub port is connected to a Phidget module)
   stat& = PhSetIsHubPortDevice(ioData.hndl, ioData.isHub)
   If stat& <> 0 Then Exit Sub

   ' SET HUB PORT
   stat& = PhSetHubPort(ioData.hndl, ioData.port)
   If stat& <> 0 Then Exit Sub

   ' SET CHANNEL
   stat& = PhSetChannel(ioData.hndl, ioData.ch)
   If stat& <> 0 Then Exit Sub
   
   ' Setup the handlers to be run when the device is plugged in,
   ' opened from software, unplugged, closed from software, or
   ' generates an error.
   ' SETUP ATTACH EVENT
   stat& = PhSetOnAttach&(ioData.hndl, _
               AddressOf PhDigOutOnAttach, _
               ioData.uDat) ' returned with event for this handle
   If stat& <> 0 Then Exit Sub

   ' SETUP DETACH EVENT
   stat& = PhSetOnDetach&(ioData.hndl, _
               AddressOf PhDigOutOnDetach, _
               ioData.uDat) ' returned with event for this handle
   If stat& <> 0 Then Exit Sub

   ' SETUP ERROR EVENT
   ' Using common Error Handler for all phidget modules.
   stat& = PhSetOnError&(ioData.hndl, _
               AddressOf PhDigOutOnError, _
               ioData.uDat) ' returned with event for this handle
   If stat& <> 0 Then Exit Sub

   ' OPEN CHANNEL
   'stat& = PhOpen(ioData.hndl)
   
   ' OPEN CHANNEL & WAIT FOR ATTACH with timeout
   stat& = PhOpenWaitForAttachment(ioData.hndl, timeOutMs&)
   
End Sub
